from CyXTraX.io import load_atlas
from CyXTraX.simulation.model import add_white_noise, add_gaussian_blur, add_material
from CyXTraX.util.visualisation import save_map_plot_with_index
from CyXTraX.util.datasets import merge_atlases

from pathlib import Path
from jax import random


# Just get the temp folder to store the atlas
FOLDER = Path("/mnt/data/xray_studies_data/")
TEMP_FOLDER = FOLDER / "dataset_64"


def main():
    files = list(TEMP_FOLDER.glob("*.h5"))
    if not files:
        raise FileNotFoundError("No .h5 files in temp folder. Run Example 02!")

    map_index = 3
    maps, points, mesh_object_list = load_atlas(files[-1])
    random_key = random.PRNGKey(42)
    save_map_plot_with_index(maps, map_index, TEMP_FOLDER / "blank_map.png")

    map_with_white_noise, white_noise_parameter, random_key = add_white_noise(
        maps, 5.3, 10.1, random_key
    )
    print(white_noise_parameter)
    save_map_plot_with_index(
        map_with_white_noise,
        map_index,
        TEMP_FOLDER / "noise_map.png",
        title="White Noise",
    )

    map_with_gaussian_blur, gaussian_blur_parameter, random_key = add_gaussian_blur(
        maps, 1.1, 3, random_key
    )
    print(gaussian_blur_parameter)
    save_map_plot_with_index(
        map_with_gaussian_blur,
        map_index,
        TEMP_FOLDER / "gaussian_map.png",
        title="Gaussian Blur",
    )

    map_with_attenuation, attenuation_parameter, random_key = add_material(
        maps, "c", 225, 30, random_key
    )
    print(attenuation_parameter)
    save_map_plot_with_index(
        map_with_attenuation,
        map_index,
        TEMP_FOLDER / "attenuation_c_map.png",
        title="Attenuation C",
    )

    merged_map = merge_atlases(map_with_gaussian_blur, map_with_white_noise)
    save_map_plot_with_index(
        merged_map,
        map_index,
        TEMP_FOLDER / "merged_map.png",
        title="Merged Map: Gaussian + Noise",
    )


if __name__ == "__main__":
    main()
